Class: FuseClient::FuseApi
- Inherits:
-
Object
- Object
- FuseClient::FuseApi
- Defined in:
- lib/fuse_client/api/fuse_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_asset_report(opts = {}) ⇒ CreateAssetReportResponse
Use this endpoint to generate an Asset Report for a user.
-
#create_asset_report_with_http_info(opts = {}) ⇒ Array<(CreateAssetReportResponse, Integer, Hash)>
Use this endpoint to generate an Asset Report for a user.
-
#create_link_token(opts = {}) ⇒ CreateLinkTokenResponse
Create a link token to start the process of a user connecting to a specific financial institution.
-
#create_link_token_with_http_info(opts = {}) ⇒ Array<(CreateLinkTokenResponse, Integer, Hash)>
Create a link token to start the process of a user connecting to a specific financial institution.
-
#create_session(opts = {}) ⇒ CreateSessionResponse
Creates a session that returns a client_secret which is required as a parameter when initializing the Fuse SDK.
-
#create_session_with_http_info(opts = {}) ⇒ Array<(CreateSessionResponse, Integer, Hash)>
Creates a session that returns a client_secret which is required as a parameter when initializing the Fuse SDK.
-
#exchange_public_token(opts = {}) ⇒ ExchangeFinancialConnectionsPublicTokenResponse
API to exchange a public token for an access token and financial connection id.
-
#exchange_public_token_with_http_info(opts = {}) ⇒ Array<(ExchangeFinancialConnectionsPublicTokenResponse, Integer, Hash)>
API to exchange a public token for an access token and financial connection id.
-
#get_asset_report(opts = {}) ⇒ GetAssetReportResponse
Retrieves the Asset Report in JSON format.
-
#get_asset_report_with_http_info(opts = {}) ⇒ Array<(GetAssetReportResponse, Integer, Hash)>
Retrieves the Asset Report in JSON format.
-
#get_financial_connections_account_details(get_financial_connections_account_details_request, opts = {}) ⇒ GetFinancialConnectionsAccountDetailsResponse
Get account details.
-
#get_financial_connections_account_details_with_http_info(get_financial_connections_account_details_request, opts = {}) ⇒ Array<(GetFinancialConnectionsAccountDetailsResponse, Integer, Hash)>
Get account details.
-
#get_financial_connections_accounts(get_financial_connections_accounts_request, opts = {}) ⇒ GetFinancialConnectionsAccountsResponse
Get accounts.
-
#get_financial_connections_accounts_with_http_info(get_financial_connections_accounts_request, opts = {}) ⇒ Array<(GetFinancialConnectionsAccountsResponse, Integer, Hash)>
Get accounts.
-
#get_financial_connections_balances(get_financial_connections_balance_request, opts = {}) ⇒ GetFinancialConnectionsAccountBalanceResponse
Get balances.
-
#get_financial_connections_balances_with_http_info(get_financial_connections_balance_request, opts = {}) ⇒ Array<(GetFinancialConnectionsAccountBalanceResponse, Integer, Hash)>
Get balances.
-
#get_financial_connections_owners(get_financial_connections_owners_request, opts = {}) ⇒ GetFinancialConnectionsOwnersResponse
Get account owners.
-
#get_financial_connections_owners_with_http_info(get_financial_connections_owners_request, opts = {}) ⇒ Array<(GetFinancialConnectionsOwnersResponse, Integer, Hash)>
Get account owners.
-
#get_financial_connections_transactions(get_transactions_request, opts = {}) ⇒ GetTransactionsResponse
Get transactions.
-
#get_financial_connections_transactions_with_http_info(get_transactions_request, opts = {}) ⇒ Array<(GetTransactionsResponse, Integer, Hash)>
Get transactions.
-
#get_investment_holdings(get_investment_holdings_request, opts = {}) ⇒ GetInvestmentHoldingsResponse
Get investment holdings.
-
#get_investment_holdings_with_http_info(get_investment_holdings_request, opts = {}) ⇒ Array<(GetInvestmentHoldingsResponse, Integer, Hash)>
Get investment holdings.
-
#get_investment_transactions(get_investment_transactions_request, opts = {}) ⇒ GetInvestmentTransactionsResponse
Get investment holdings.
-
#get_investment_transactions_with_http_info(get_investment_transactions_request, opts = {}) ⇒ Array<(GetInvestmentTransactionsResponse, Integer, Hash)>
Get investment holdings.
-
#initialize(api_client = ApiClient.default) ⇒ FuseApi
constructor
A new instance of FuseApi.
-
#sync_financial_connections_data(body, opts = {}) ⇒ SyncFinancialConnectionsDataResponse
Sync financial connections data Call this endpoint upon receiving a SYNC_REQUIRED webhook.
-
#sync_financial_connections_data_with_http_info(body, opts = {}) ⇒ Array<(SyncFinancialConnectionsDataResponse, Integer, Hash)>
Sync financial connections data Call this endpoint upon receiving a SYNC_REQUIRED webhook.
-
#sync_financial_connections_transactions(sync_transactions_request, opts = {}) ⇒ SyncTransactionsResponse
Sync transactions.
-
#sync_financial_connections_transactions_with_http_info(sync_transactions_request, opts = {}) ⇒ Array<(SyncTransactionsResponse, Integer, Hash)>
Sync transactions.
-
#v1_financial_connections_liabilities_post(get_liabilities_request, opts = {}) ⇒ GetLiabilitiesResponse
Get liabilities.
-
#v1_financial_connections_liabilities_post_with_http_info(get_liabilities_request, opts = {}) ⇒ Array<(GetLiabilitiesResponse, Integer, Hash)>
Get liabilities.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ FuseApi
Returns a new instance of FuseApi.
19 20 21 |
# File 'lib/fuse_client/api/fuse_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/fuse_client/api/fuse_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_asset_report(opts = {}) ⇒ CreateAssetReportResponse
Use this endpoint to generate an Asset Report for a user.
26 27 28 29 |
# File 'lib/fuse_client/api/fuse_api.rb', line 26 def create_asset_report(opts = {}) data, _status_code, _headers = create_asset_report_with_http_info(opts) data end |
#create_asset_report_with_http_info(opts = {}) ⇒ Array<(CreateAssetReportResponse, Integer, Hash)>
Use this endpoint to generate an Asset Report for a user.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/fuse_client/api/fuse_api.rb', line 35 def create_asset_report_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FuseApi.create_asset_report ...' end # resource path local_var_path = '/v1/asset_report/create' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'create_asset_report_request']) # return_type return_type = opts[:debug_return_type] || 'CreateAssetReportResponse' # auth_names auth_names = opts[:debug_auth_names] || ['fuseApiKey', 'fuseClientId'] = opts.merge( :operation => :"FuseApi.create_asset_report", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FuseApi#create_asset_report\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_link_token(opts = {}) ⇒ CreateLinkTokenResponse
Create a link token to start the process of a user connecting to a specific financial institution.
88 89 90 91 |
# File 'lib/fuse_client/api/fuse_api.rb', line 88 def create_link_token(opts = {}) data, _status_code, _headers = create_link_token_with_http_info(opts) data end |
#create_link_token_with_http_info(opts = {}) ⇒ Array<(CreateLinkTokenResponse, Integer, Hash)>
Create a link token to start the process of a user connecting to a specific financial institution.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/fuse_client/api/fuse_api.rb', line 97 def create_link_token_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FuseApi.create_link_token ...' end # resource path local_var_path = '/v1/link/token' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'create_link_token_request']) # return_type return_type = opts[:debug_return_type] || 'CreateLinkTokenResponse' # auth_names auth_names = opts[:debug_auth_names] || ['fuseApiKey', 'fuseClientId'] = opts.merge( :operation => :"FuseApi.create_link_token", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FuseApi#create_link_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_session(opts = {}) ⇒ CreateSessionResponse
Creates a session that returns a client_secret which is required as a parameter when initializing the Fuse SDK.
150 151 152 153 |
# File 'lib/fuse_client/api/fuse_api.rb', line 150 def create_session(opts = {}) data, _status_code, _headers = create_session_with_http_info(opts) data end |
#create_session_with_http_info(opts = {}) ⇒ Array<(CreateSessionResponse, Integer, Hash)>
Creates a session that returns a client_secret which is required as a parameter when initializing the Fuse SDK.
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/fuse_client/api/fuse_api.rb', line 159 def create_session_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FuseApi.create_session ...' end # resource path local_var_path = '/v1/session' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'create_session_request']) # return_type return_type = opts[:debug_return_type] || 'CreateSessionResponse' # auth_names auth_names = opts[:debug_auth_names] || ['fuseApiKey', 'fuseClientId'] = opts.merge( :operation => :"FuseApi.create_session", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FuseApi#create_session\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#exchange_public_token(opts = {}) ⇒ ExchangeFinancialConnectionsPublicTokenResponse
API to exchange a public token for an access token and financial connection id
212 213 214 215 |
# File 'lib/fuse_client/api/fuse_api.rb', line 212 def exchange_public_token(opts = {}) data, _status_code, _headers = exchange_public_token_with_http_info(opts) data end |
#exchange_public_token_with_http_info(opts = {}) ⇒ Array<(ExchangeFinancialConnectionsPublicTokenResponse, Integer, Hash)>
API to exchange a public token for an access token and financial connection id
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/fuse_client/api/fuse_api.rb', line 221 def exchange_public_token_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FuseApi.exchange_public_token ...' end # resource path local_var_path = '/v1/financial_connections/public_token/exchange' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'exchange_financial_connections_public_token_request']) # return_type return_type = opts[:debug_return_type] || 'ExchangeFinancialConnectionsPublicTokenResponse' # auth_names auth_names = opts[:debug_auth_names] || ['fuseApiKey', 'fuseClientId'] = opts.merge( :operation => :"FuseApi.exchange_public_token", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FuseApi#exchange_public_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_asset_report(opts = {}) ⇒ GetAssetReportResponse
Retrieves the Asset Report in JSON format.
274 275 276 277 |
# File 'lib/fuse_client/api/fuse_api.rb', line 274 def get_asset_report(opts = {}) data, _status_code, _headers = get_asset_report_with_http_info(opts) data end |
#get_asset_report_with_http_info(opts = {}) ⇒ Array<(GetAssetReportResponse, Integer, Hash)>
Retrieves the Asset Report in JSON format.
283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/fuse_client/api/fuse_api.rb', line 283 def get_asset_report_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FuseApi.get_asset_report ...' end # resource path local_var_path = '/v1/asset_report' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'get_asset_report_request']) # return_type return_type = opts[:debug_return_type] || 'GetAssetReportResponse' # auth_names auth_names = opts[:debug_auth_names] || ['fuseApiKey', 'fuseClientId'] = opts.merge( :operation => :"FuseApi.get_asset_report", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FuseApi#get_asset_report\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_financial_connections_account_details(get_financial_connections_account_details_request, opts = {}) ⇒ GetFinancialConnectionsAccountDetailsResponse
Get account details
336 337 338 339 |
# File 'lib/fuse_client/api/fuse_api.rb', line 336 def get_financial_connections_account_details(get_financial_connections_account_details_request, opts = {}) data, _status_code, _headers = get_financial_connections_account_details_with_http_info(get_financial_connections_account_details_request, opts) data end |
#get_financial_connections_account_details_with_http_info(get_financial_connections_account_details_request, opts = {}) ⇒ Array<(GetFinancialConnectionsAccountDetailsResponse, Integer, Hash)>
Get account details
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/fuse_client/api/fuse_api.rb', line 345 def get_financial_connections_account_details_with_http_info(get_financial_connections_account_details_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FuseApi.get_financial_connections_account_details ...' end # verify the required parameter 'get_financial_connections_account_details_request' is set if @api_client.config.client_side_validation && get_financial_connections_account_details_request.nil? fail ArgumentError, "Missing the required parameter 'get_financial_connections_account_details_request' when calling FuseApi.get_financial_connections_account_details" end # resource path local_var_path = '/v1/financial_connections/accounts/details' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(get_financial_connections_account_details_request) # return_type return_type = opts[:debug_return_type] || 'GetFinancialConnectionsAccountDetailsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['fuseApiKey', 'fuseClientId'] = opts.merge( :operation => :"FuseApi.get_financial_connections_account_details", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FuseApi#get_financial_connections_account_details\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_financial_connections_accounts(get_financial_connections_accounts_request, opts = {}) ⇒ GetFinancialConnectionsAccountsResponse
Get accounts
402 403 404 405 |
# File 'lib/fuse_client/api/fuse_api.rb', line 402 def get_financial_connections_accounts(get_financial_connections_accounts_request, opts = {}) data, _status_code, _headers = get_financial_connections_accounts_with_http_info(get_financial_connections_accounts_request, opts) data end |
#get_financial_connections_accounts_with_http_info(get_financial_connections_accounts_request, opts = {}) ⇒ Array<(GetFinancialConnectionsAccountsResponse, Integer, Hash)>
Get accounts
411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/fuse_client/api/fuse_api.rb', line 411 def get_financial_connections_accounts_with_http_info(get_financial_connections_accounts_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FuseApi.get_financial_connections_accounts ...' end # verify the required parameter 'get_financial_connections_accounts_request' is set if @api_client.config.client_side_validation && get_financial_connections_accounts_request.nil? fail ArgumentError, "Missing the required parameter 'get_financial_connections_accounts_request' when calling FuseApi.get_financial_connections_accounts" end # resource path local_var_path = '/v1/financial_connections/accounts' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(get_financial_connections_accounts_request) # return_type return_type = opts[:debug_return_type] || 'GetFinancialConnectionsAccountsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['fuseApiKey', 'fuseClientId'] = opts.merge( :operation => :"FuseApi.get_financial_connections_accounts", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FuseApi#get_financial_connections_accounts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_financial_connections_balances(get_financial_connections_balance_request, opts = {}) ⇒ GetFinancialConnectionsAccountBalanceResponse
Get balances
468 469 470 471 |
# File 'lib/fuse_client/api/fuse_api.rb', line 468 def get_financial_connections_balances(get_financial_connections_balance_request, opts = {}) data, _status_code, _headers = get_financial_connections_balances_with_http_info(get_financial_connections_balance_request, opts) data end |
#get_financial_connections_balances_with_http_info(get_financial_connections_balance_request, opts = {}) ⇒ Array<(GetFinancialConnectionsAccountBalanceResponse, Integer, Hash)>
Get balances
477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 |
# File 'lib/fuse_client/api/fuse_api.rb', line 477 def get_financial_connections_balances_with_http_info(get_financial_connections_balance_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FuseApi.get_financial_connections_balances ...' end # verify the required parameter 'get_financial_connections_balance_request' is set if @api_client.config.client_side_validation && get_financial_connections_balance_request.nil? fail ArgumentError, "Missing the required parameter 'get_financial_connections_balance_request' when calling FuseApi.get_financial_connections_balances" end # resource path local_var_path = '/v1/financial_connections/balances' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(get_financial_connections_balance_request) # return_type return_type = opts[:debug_return_type] || 'GetFinancialConnectionsAccountBalanceResponse' # auth_names auth_names = opts[:debug_auth_names] || ['fuseApiKey', 'fuseClientId'] = opts.merge( :operation => :"FuseApi.get_financial_connections_balances", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FuseApi#get_financial_connections_balances\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_financial_connections_owners(get_financial_connections_owners_request, opts = {}) ⇒ GetFinancialConnectionsOwnersResponse
Get account owners
534 535 536 537 |
# File 'lib/fuse_client/api/fuse_api.rb', line 534 def get_financial_connections_owners(get_financial_connections_owners_request, opts = {}) data, _status_code, _headers = get_financial_connections_owners_with_http_info(get_financial_connections_owners_request, opts) data end |
#get_financial_connections_owners_with_http_info(get_financial_connections_owners_request, opts = {}) ⇒ Array<(GetFinancialConnectionsOwnersResponse, Integer, Hash)>
Get account owners
543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 |
# File 'lib/fuse_client/api/fuse_api.rb', line 543 def get_financial_connections_owners_with_http_info(get_financial_connections_owners_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FuseApi.get_financial_connections_owners ...' end # verify the required parameter 'get_financial_connections_owners_request' is set if @api_client.config.client_side_validation && get_financial_connections_owners_request.nil? fail ArgumentError, "Missing the required parameter 'get_financial_connections_owners_request' when calling FuseApi.get_financial_connections_owners" end # resource path local_var_path = '/v1/financial_connections/owners' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(get_financial_connections_owners_request) # return_type return_type = opts[:debug_return_type] || 'GetFinancialConnectionsOwnersResponse' # auth_names auth_names = opts[:debug_auth_names] || ['fuseApiKey', 'fuseClientId'] = opts.merge( :operation => :"FuseApi.get_financial_connections_owners", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FuseApi#get_financial_connections_owners\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_financial_connections_transactions(get_transactions_request, opts = {}) ⇒ GetTransactionsResponse
Get transactions
600 601 602 603 |
# File 'lib/fuse_client/api/fuse_api.rb', line 600 def get_financial_connections_transactions(get_transactions_request, opts = {}) data, _status_code, _headers = get_financial_connections_transactions_with_http_info(get_transactions_request, opts) data end |
#get_financial_connections_transactions_with_http_info(get_transactions_request, opts = {}) ⇒ Array<(GetTransactionsResponse, Integer, Hash)>
Get transactions
609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 |
# File 'lib/fuse_client/api/fuse_api.rb', line 609 def get_financial_connections_transactions_with_http_info(get_transactions_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FuseApi.get_financial_connections_transactions ...' end # verify the required parameter 'get_transactions_request' is set if @api_client.config.client_side_validation && get_transactions_request.nil? fail ArgumentError, "Missing the required parameter 'get_transactions_request' when calling FuseApi.get_financial_connections_transactions" end # resource path local_var_path = '/v1/financial_connections/transactions' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(get_transactions_request) # return_type return_type = opts[:debug_return_type] || 'GetTransactionsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['fuseApiKey', 'fuseClientId'] = opts.merge( :operation => :"FuseApi.get_financial_connections_transactions", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FuseApi#get_financial_connections_transactions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_investment_holdings(get_investment_holdings_request, opts = {}) ⇒ GetInvestmentHoldingsResponse
Get investment holdings
666 667 668 669 |
# File 'lib/fuse_client/api/fuse_api.rb', line 666 def get_investment_holdings(get_investment_holdings_request, opts = {}) data, _status_code, _headers = get_investment_holdings_with_http_info(get_investment_holdings_request, opts) data end |
#get_investment_holdings_with_http_info(get_investment_holdings_request, opts = {}) ⇒ Array<(GetInvestmentHoldingsResponse, Integer, Hash)>
Get investment holdings
675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 |
# File 'lib/fuse_client/api/fuse_api.rb', line 675 def get_investment_holdings_with_http_info(get_investment_holdings_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FuseApi.get_investment_holdings ...' end # verify the required parameter 'get_investment_holdings_request' is set if @api_client.config.client_side_validation && get_investment_holdings_request.nil? fail ArgumentError, "Missing the required parameter 'get_investment_holdings_request' when calling FuseApi.get_investment_holdings" end # resource path local_var_path = '/v1/financial_connections/investments/holdings' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(get_investment_holdings_request) # return_type return_type = opts[:debug_return_type] || 'GetInvestmentHoldingsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['fuseApiKey', 'fuseClientId'] = opts.merge( :operation => :"FuseApi.get_investment_holdings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FuseApi#get_investment_holdings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_investment_transactions(get_investment_transactions_request, opts = {}) ⇒ GetInvestmentTransactionsResponse
Get investment holdings
732 733 734 735 |
# File 'lib/fuse_client/api/fuse_api.rb', line 732 def get_investment_transactions(get_investment_transactions_request, opts = {}) data, _status_code, _headers = get_investment_transactions_with_http_info(get_investment_transactions_request, opts) data end |
#get_investment_transactions_with_http_info(get_investment_transactions_request, opts = {}) ⇒ Array<(GetInvestmentTransactionsResponse, Integer, Hash)>
Get investment holdings
741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 |
# File 'lib/fuse_client/api/fuse_api.rb', line 741 def get_investment_transactions_with_http_info(get_investment_transactions_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FuseApi.get_investment_transactions ...' end # verify the required parameter 'get_investment_transactions_request' is set if @api_client.config.client_side_validation && get_investment_transactions_request.nil? fail ArgumentError, "Missing the required parameter 'get_investment_transactions_request' when calling FuseApi.get_investment_transactions" end # resource path local_var_path = '/v1/financial_connections/investments/transactions' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(get_investment_transactions_request) # return_type return_type = opts[:debug_return_type] || 'GetInvestmentTransactionsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['fuseApiKey', 'fuseClientId'] = opts.merge( :operation => :"FuseApi.get_investment_transactions", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FuseApi#get_investment_transactions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#sync_financial_connections_data(body, opts = {}) ⇒ SyncFinancialConnectionsDataResponse
Sync financial connections data Call this endpoint upon receiving a SYNC_REQUIRED webhook. This will keep the financial connections data up to date.
799 800 801 802 |
# File 'lib/fuse_client/api/fuse_api.rb', line 799 def sync_financial_connections_data(body, opts = {}) data, _status_code, _headers = sync_financial_connections_data_with_http_info(body, opts) data end |
#sync_financial_connections_data_with_http_info(body, opts = {}) ⇒ Array<(SyncFinancialConnectionsDataResponse, Integer, Hash)>
Sync financial connections data Call this endpoint upon receiving a SYNC_REQUIRED webhook. This will keep the financial connections data up to date.
809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 |
# File 'lib/fuse_client/api/fuse_api.rb', line 809 def sync_financial_connections_data_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FuseApi.sync_financial_connections_data ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling FuseApi.sync_financial_connections_data" end # resource path local_var_path = '/v1/financial_connections/sync' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'SyncFinancialConnectionsDataResponse' # auth_names auth_names = opts[:debug_auth_names] || ['fuseApiKey', 'fuseClientId'] = opts.merge( :operation => :"FuseApi.sync_financial_connections_data", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FuseApi#sync_financial_connections_data\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#sync_financial_connections_transactions(sync_transactions_request, opts = {}) ⇒ SyncTransactionsResponse
Sync transactions
866 867 868 869 |
# File 'lib/fuse_client/api/fuse_api.rb', line 866 def sync_financial_connections_transactions(sync_transactions_request, opts = {}) data, _status_code, _headers = sync_financial_connections_transactions_with_http_info(sync_transactions_request, opts) data end |
#sync_financial_connections_transactions_with_http_info(sync_transactions_request, opts = {}) ⇒ Array<(SyncTransactionsResponse, Integer, Hash)>
Sync transactions
875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 |
# File 'lib/fuse_client/api/fuse_api.rb', line 875 def sync_financial_connections_transactions_with_http_info(sync_transactions_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FuseApi.sync_financial_connections_transactions ...' end # verify the required parameter 'sync_transactions_request' is set if @api_client.config.client_side_validation && sync_transactions_request.nil? fail ArgumentError, "Missing the required parameter 'sync_transactions_request' when calling FuseApi.sync_financial_connections_transactions" end # resource path local_var_path = '/v1/financial_connections/transactions/sync' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(sync_transactions_request) # return_type return_type = opts[:debug_return_type] || 'SyncTransactionsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['fuseApiKey', 'fuseClientId'] = opts.merge( :operation => :"FuseApi.sync_financial_connections_transactions", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FuseApi#sync_financial_connections_transactions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_financial_connections_liabilities_post(get_liabilities_request, opts = {}) ⇒ GetLiabilitiesResponse
Get liabilities
932 933 934 935 |
# File 'lib/fuse_client/api/fuse_api.rb', line 932 def v1_financial_connections_liabilities_post(get_liabilities_request, opts = {}) data, _status_code, _headers = v1_financial_connections_liabilities_post_with_http_info(get_liabilities_request, opts) data end |
#v1_financial_connections_liabilities_post_with_http_info(get_liabilities_request, opts = {}) ⇒ Array<(GetLiabilitiesResponse, Integer, Hash)>
Get liabilities
941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 |
# File 'lib/fuse_client/api/fuse_api.rb', line 941 def v1_financial_connections_liabilities_post_with_http_info(get_liabilities_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FuseApi.v1_financial_connections_liabilities_post ...' end # verify the required parameter 'get_liabilities_request' is set if @api_client.config.client_side_validation && get_liabilities_request.nil? fail ArgumentError, "Missing the required parameter 'get_liabilities_request' when calling FuseApi.v1_financial_connections_liabilities_post" end # resource path local_var_path = '/v1/financial_connections/liabilities' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(get_liabilities_request) # return_type return_type = opts[:debug_return_type] || 'GetLiabilitiesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['fuseApiKey', 'fuseClientId'] = opts.merge( :operation => :"FuseApi.v1_financial_connections_liabilities_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FuseApi#v1_financial_connections_liabilities_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |