Class: FuseClient::GetTransactionsResponseDataInner
- Inherits:
-
Object
- Object
- FuseClient::GetTransactionsResponseDataInner
- Defined in:
- lib/fuse_client/models/get_transactions_response_data_inner.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount in cents associated with the transaction.
-
#category ⇒ Object
Categories of the transaction, ie Computers and Electronics.
-
#date ⇒ Object
Date of the transaction.
-
#description ⇒ Object
Description of the transaction.
-
#id ⇒ Object
Fuse Id of the transaction.
-
#merchant ⇒ Object
Returns the value of attribute merchant.
-
#remote_account_id ⇒ Object
Remote Account Id of the transaction, ie Plaid Account Id.
-
#remote_data ⇒ Object
The exact data from the aggregator (ie plaid) that we retrieved the information from.
-
#remote_id ⇒ Object
Remote Id of the transaction, ie Plaid or Teller Id.
-
#status ⇒ Object
The status of the transaction.
-
#type ⇒ Object
Type of the transaction, ie adjustment.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetTransactionsResponseDataInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ GetTransactionsResponseDataInner
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 97 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FuseClient::GetTransactionsResponseDataInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FuseClient::GetTransactionsResponseDataInner`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'remote_id') self.remote_id = attributes[:'remote_id'] end if attributes.key?(:'remote_account_id') self.remote_account_id = attributes[:'remote_account_id'] end if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'date') self.date = attributes[:'date'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'category') if (value = attributes[:'category']).is_a?(Array) self.category = value end end if attributes.key?(:'merchant') self.merchant = attributes[:'merchant'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'remote_data') self.remote_data = attributes[:'remote_data'] end end |
Instance Attribute Details
#amount ⇒ Object
Amount in cents associated with the transaction
28 29 30 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 28 def amount @amount end |
#category ⇒ Object
Categories of the transaction, ie Computers and Electronics
37 38 39 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 37 def category @category end |
#date ⇒ Object
Date of the transaction
31 32 33 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 31 def date @date end |
#description ⇒ Object
Description of the transaction
34 35 36 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 34 def description @description end |
#id ⇒ Object
Fuse Id of the transaction
19 20 21 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 19 def id @id end |
#merchant ⇒ Object
Returns the value of attribute merchant.
39 40 41 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 39 def merchant @merchant end |
#remote_account_id ⇒ Object
Remote Account Id of the transaction, ie Plaid Account Id
25 26 27 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 25 def remote_account_id @remote_account_id end |
#remote_data ⇒ Object
The exact data from the aggregator (ie plaid) that we retrieved the information from
48 49 50 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 48 def remote_data @remote_data end |
#remote_id ⇒ Object
Remote Id of the transaction, ie Plaid or Teller Id
22 23 24 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 22 def remote_id @remote_id end |
#status ⇒ Object
The status of the transaction. This will be either POSTED or PENDING.
42 43 44 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 42 def status @status end |
#type ⇒ Object
Type of the transaction, ie adjustment
45 46 47 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 45 def type @type end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 68 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 51 def self.attribute_map { :'id' => :'id', :'remote_id' => :'remote_id', :'remote_account_id' => :'remote_account_id', :'amount' => :'amount', :'date' => :'date', :'description' => :'description', :'category' => :'category', :'merchant' => :'merchant', :'status' => :'status', :'type' => :'type', :'remote_data' => :'remote_data' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
203 204 205 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 203 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
90 91 92 93 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 90 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 73 def self.openapi_types { :'id' => :'String', :'remote_id' => :'String', :'remote_account_id' => :'String', :'amount' => :'Float', :'date' => :'String', :'description' => :'String', :'category' => :'Array<String>', :'merchant' => :'GetTransactionsResponseDataInnerMerchant', :'status' => :'String', :'type' => :'String', :'remote_data' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 172 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && remote_id == o.remote_id && remote_account_id == o.remote_account_id && amount == o.amount && date == o.date && description == o.description && category == o.category && merchant == o.merchant && status == o.status && type == o.type && remote_data == o.remote_data end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 234 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = FuseClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 305 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 210 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
190 191 192 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 190 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
196 197 198 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 196 def hash [id, remote_id, remote_account_id, amount, date, description, category, merchant, status, type, remote_data].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
159 160 161 162 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 159 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
281 282 283 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 281 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 287 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
275 276 277 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 275 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
166 167 168 |
# File 'lib/fuse_client/models/get_transactions_response_data_inner.rb', line 166 def valid? true end |